@@ -1078,7 +1078,7 @@ const ChatView = new Lang.Class({
 
             let start = buffer.get_iter_at_mark(headerMark);
             let end = start.copy();
-            end.forward_to_line_end(headerTag);
+            end.forward_to_line_end();
             buffer.delete(start, end);
         }
 
@@ -1331,6 +1331,13 @@ const ChatView = new Lang.Class({
     },
 
     _onNickStatusChanged: function(baseNick, status) {
+        if (this._room.type == Tp.HandleType.CONTACT &&
+            status == Tp.ConnectionPresenceType.OFFLINE &&
+            this._room.channel)
+            this._room.channel.ack_all_pending_messages_async(() => {
+                this._room.channel.close_async(null);
+            });
+
         let nickTagName = this._getNickTagName(baseNick);
         let nickTag = this._lookupTag(nickTagName);
 
