@@ -3,7 +3,6 @@ const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Tp = imports.gi.TelepathyGLib;
-const Tpl = imports.gi.TelepathyLogger;
 const GObject = imports.gi.GObject;
 
 const AccountsMonitor = imports.accountsMonitor;
@@ -25,13 +24,10 @@ const JoinDialog = new Lang.Class({
                        'mainStack',
                        'connectionCombo',
                        'connectionButton',
-                       'nameCompletion',
                        'connectionStack',
                        'filterEntry',
                        'connectionsList',
                        'serverRoomList',
-                       'nameEntry',
-                       'spinner',
                        'details',
                        'addButton',
                        'customToggle'],
@@ -113,12 +109,8 @@ const JoinDialog = new Lang.Class({
                                       Lang.bind(this, this._onAccountChanged));
         this._connectionCombo.sensitive = false;
 
-        this._nameEntry.connect('changed',
-                                Lang.bind(this, this._updateCanJoin));
         this._serverRoomList.connect('notify::can-join',
                                      Lang.bind(this, this._updateCanJoin));
-        this._serverRoomList.bind_property('loading', this._spinner, 'active',
-                                            GObject.BindingFlags.SYNC_CREATE);
     },
 
     _setupConnectionPage: function() {
@@ -171,33 +163,10 @@ const JoinDialog = new Lang.Class({
     },
 
     _onAccountChanged: function() {
-        this._nameEntry.set_text('');
-        this._nameCompletion.model.clear();
-
         let selected = this._connectionCombo.get_active_text();
         let account = this._accounts[selected];
         if (!account)
             return;
-        let logManager = Tpl.LogManager.dup_singleton();
-
-        logManager.get_entities_async(account, Lang.bind(this,
-            function(m, res) {
-                let [, entities] = logManager.get_entities_finish(res);
-                let names = entities.filter(function(e) {
-                    return e.type == Tpl.EntityType.ROOM;
-                }).map(function(e) {
-                    return e.alias;
-                });
-                for (let i = 0; i < names.length; i++) {
-                    let model = this._nameCompletion.model;
-                    let iter = model.append();
-                    model.set_value(iter, 0, names[i]);
-                    if (names[i].startsWith('#')) {
-                        iter = model.append();
-                        model.set_value(iter, 0, names[i].substr(1));
-                    }
-                }
-            }));
 
        this._serverRoomList.setAccount(account);
     },
@@ -213,9 +182,6 @@ const JoinDialog = new Lang.Class({
         let account = this._accounts[selected];
 
         let toJoinRooms = this._serverRoomList.selectedRooms;
-        if (this._nameEntry.get_text_length() > 0)
-            toJoinRooms.push(this._nameEntry.get_text());
-
         toJoinRooms.forEach(function(room) {
             if (room[0] != '#')
                 room = '#' + room;
@@ -254,8 +220,7 @@ const JoinDialog = new Lang.Class({
 
         if (this._page == DialogPage.MAIN)
             sensitive = this._connectionCombo.get_active() > -1  &&
-                        (this._nameEntry.get_text_length() > 0 ||
-                        this._serverRoomList.can_join);
+                        this._serverRoomList.can_join;
 
         this._joinButton.sensitive = sensitive;
         this.set_default_response(sensitive ? Gtk.ResponseType.OK
@@ -274,7 +239,7 @@ const JoinDialog = new Lang.Class({
         let isAccountsEmpty = !this._hasAccounts;
 
         if (isMain)
-            this._nameEntry.grab_focus();
+            this._serverRoomList.focusEntry();
         else
             this._customToggle.active = false;
 
