@@ -131,6 +131,8 @@ const UserDetails = new Lang.Class({
 
         this._expanded = false;
         this._initialDetailsLoaded = false;
+        this._notificationsEnabled = false;
+        this._user = null;
 
         this.parent(params);
 
@@ -141,6 +143,7 @@ const UserDetails = new Lang.Class({
 
         this._updateButtonVisibility();
         this._detailsGrid.hide();
+        this._notificationLabel.opacity = this.notifications_enabled ? 1. : 0.;
     },
 
     get notifications_enabled() {
@@ -340,6 +343,9 @@ const UserPopover = new Lang.Class({
         this._userTracker = params.userTracker;
         delete params.userTracker;
 
+        this._nickname = null;
+        this._basenick = null;
+
         this.parent(params);
 
         this._nickLabel.set_state_flags(Gtk.StateFlags.LINK, false);
